@@ -676,14 +676,20 @@ where
         Ok(())
     }
 
-    pub fn compact(&self) -> TractResult<Self> {
+    pub fn compact(&mut self) -> TractResult<()> {
         use crate::model::translator::Translate;
-        let result = crate::model::translator::IntoTranslator.translate_model(self)?;
+        let mut result = crate::model::translator::IntoTranslator.translate_model(self)?;
         #[cfg(debug_assertions)]
         {
-            result.check_compact()?;
+            result.check_compact().context("after graph compaction")?;
         }
-        Ok(result)
+        std::mem::swap(self, &mut result);
+        Ok(())
+    }
+
+    pub fn into_compact(mut self) -> TractResult<Self> {
+        self.compact()?;
+        Ok(self)
     }
 }
 
