@@ -93,6 +93,15 @@ pub trait BinMiniOp:
         Ok(None)
     }
     #[allow(unused_variables)]
+    fn codegen_unary(
+        &self,
+        model: &TypedModel,
+        node: &TypedNode,
+        a: &Arc<Tensor>,
+    ) -> TractResult<Option<TypedModelPatch>> {
+        Ok(None)
+    }
+    #[allow(unused_variables)]
     fn cost_per_element(&self, dt: DatumType) -> TVec<(Cost, usize)> {
         tvec!()
     }
@@ -341,7 +350,7 @@ impl_dyn_hash!(UnaryOp);
 
 impl Op for UnaryOp {
     fn name(&self) -> Cow<str> {
-        self.mini_op.name().into()
+        format!("{}Unary", self.mini_op.name()).into()
     }
 
     fn info(&self) -> TractResult<Vec<String>> {
@@ -463,6 +472,16 @@ impl TypedOp for UnaryOp {
         })
     }
 
+    fn codegen(
+        &self,
+        model: &TypedModel,
+        node: &TypedNode,
+    ) -> TractResult<Option<TypedModelPatch>> {
+        self.mini_op.codegen_unary(model, node, &self.a).with_context(|| {
+            format!("In specific codegen_unary for bin mini op {}", self.mini_op.name())
+        })
+    }
+
     fn change_axes(
         &self,
         model: &TypedModel,
@@ -488,7 +507,7 @@ impl_dyn_hash!(MergeOpUnicast);
 
 impl Op for MergeOpUnicast {
     fn name(&self) -> Cow<str> {
-        self.0.name().into()
+        format!("{}Unicast", self.0.name()).into()
     }
 
     op_core_lir_mir!();
@@ -542,6 +561,7 @@ impl TypedOp for MergeOpUnicast {
 macro_rules! bin_to_super_type {
     ($func:ident, $Op:ident,
      $(cost: $cost:expr,)?
+     $(codegen_unary: $codegen_unary:expr,)?
      $(declutter_bin: $declutter_bin:expr,)?
      $(declutter_unary: $declutter_unary:expr,)?
      $(eval_override: $eval_override: expr,)?
@@ -700,6 +720,16 @@ macro_rules! bin_to_super_type {
                         ($declutter_bin)(self, model, node)
                     }
                  )?
+                $(
+                    fn codegen_unary(
+                        &self,
+                        model: &TypedModel,
+                        node: &TypedNode,
+                        a: &Arc<Tensor>,
+                        ) -> TractResult<Option<TypedModelPatch>> {
+                        ($codegen_unary)(self, model, node, a)
+                    }
+                 )?
                 $(
                     fn declutter_unary(
                         &self,
@@ -741,6 +771,8 @@ macro_rules! bin_to_super_type {
 macro_rules! bin_to_bool {
     ($func:ident, $Op:ident,
      $( cost: $cost:expr, )?
+     $( codegen_unary: $codegen_unary:expr, )?
+     $( declutter_unary: $declutter_unary:expr, )?
      $( flip: $flip:expr, )?
      $( [$($typ:ident),*] => $cab:expr),*) => {
         #[derive(Debug, Clone, Hash)]
@@ -814,6 +846,29 @@ macro_rules! bin_to_bool {
                 Ok(bool::datum_type())
             }
 
+            $(
+                fn codegen_unary(
+                    &self,
+                    model: &TypedModel,
+                    node: &TypedNode,
+                    a: &Arc<Tensor>,
+                    ) -> TractResult<Option<TypedModelPatch>> {
+                    ($codegen_unary)(self, model, node, a)
+                }
+             )?
+
+
+            $(
+                fn declutter_unary(
+                    &self,
+                    model: &TypedModel,
+                    node: &TypedNode,
+                    a: &Arc<Tensor>,
+                    ) -> TractResult<Option<TypedModelPatch>> {
+                    ($declutter_unary)(self, model, node, a)
+                }
+             )?
+
             $(
                 fn unary_with_b_const(&self, b: &Arc<Tensor>) -> Option<$crate::ops::binary::UnaryOp> {
                     ($flip)(self, b)
