@@ -113,7 +113,11 @@ impl Op for LirMatMulUnary {
             "c_shape:{:?}, c_m_axis:{} c_n_axis:{} b_storage:{:?}",
             self.c_fact, self.c_m_axis, self.c_n_axis, self.geometry,
         )];
-        infos.push(format!("Mult: {}", self.mmm));
+        if let Some(geo) = self.geometry.as_concrete() {
+            infos.push(format!("Mult: m:{} k:{} n:{} with {}", geo.m, geo.k, geo.n, self.mmm));
+        } else {
+            infos.push(format!("Mult: {}", self.mmm));
+        }
         infos.push(format!("Ops: {:?}", self.micro_ops));
         Ok(infos)
     }
@@ -204,7 +208,7 @@ fn eval(
         debug_assert!(op.micro_ops.len() > 0);
         let size_of_a = (&*op.micro_ops.as_ptr()).0.datum_type().size_of();
         let mut c = Tensor::uninitialized_dt(op.c_fact.datum_type, &c_shape)?;
-        let c_storage = op.mmm.c_view_with_axis(c_m_axis, c_n_axis);
+        let c_storage = op.mmm.c_view(c_m_axis, c_n_axis);
         if op
             .c_fact
             .shape
@@ -233,7 +237,7 @@ fn eval(
                     a: op.mmm.a_packed(size_of_a, geometry.k).wrap(&pa.view()),
                     b: geometry
                         .b_storage
-                        .wrap(&TensorView::at_prefix_unchecked(&inputs[0], &*b_prefix)),
+                        .wrap(&TensorView::at_prefix_unchecked(&inputs[0], &*b_prefix))?,
                 });
                 f.extend(fused.iter().map(|f| f.resolve(inputs, &c_storage, c_store)));
                 op.mmm.run_with_scratch_space(geometry.m, geometry.n, scratch, &f)?;
@@ -245,7 +249,7 @@ fn eval(
             f.push(FusedSpec::AddMatMul {
                 k: geometry.k,
                 a: op.mmm.a_packed(size_of_a, geometry.k).wrap(&pa.view()),
-                b: geometry.b_storage.wrap(&inputs[0].view()),
+                b: geometry.b_storage.wrap(&inputs[0].view())?,
             });
             for ix in 0..fused.len() {
                 f.push(fused.get_unchecked(ix).resolve(inputs, &c_storage, c_store));
@@ -310,35 +314,36 @@ impl TypedOp for LirMatMulUnary {
             }
         }
 
-        if let Some(op) = succ.op_as::<ops::element_wise::ElementWiseOp>().map(|ew| ew.0.as_ref()) {
-            if let Some(cast) = op.downcast_ref::<ops::cast::Cast>().map(|cast| cast.to) {
-                if (cast.unquantized() == i8::datum_type()
-                    || cast.unquantized() == u8::datum_type())
-                    && self.c_fact.datum_type == i32::datum_type()
-                {
-                    let at = self.micro_ops.iter().nth(0).unwrap().0.datum_type();
-                    let bt = model.outlet_fact(node.inputs[0])?.datum_type;
-                    let mmm = tract_linalg::ops()
-                        .mmm(
-                            at,
-                            bt,
-                            i8::datum_type(),
-                            self.c_fact.shape[self.c_m_axis].to_usize().ok(),
-                            None,
-                            self.c_fact.shape[self.c_n_axis].to_usize().ok(),
-                        )
-                        .unwrap();
+        if let Some(cast) = succ.op_as::<ops::cast::Cast>().map(|cast| cast.to) {
+            if (cast.unquantized() == i8::datum_type() || cast.unquantized() == u8::datum_type())
+                && self.c_fact.datum_type == i32::datum_type()
+            {
+                let at = self.micro_ops.iter().nth(0).unwrap().0.datum_type();
+                let bt = model.outlet_fact(node.inputs[0])?.datum_type;
+                let mmm = tract_linalg::ops()
+                    .mmm(
+                        at,
+                        bt,
+                        i8::datum_type(),
+                        self.c_fact.shape[self.c_m_axis].to_usize().ok(),
+                        None,
+                        self.c_fact.shape[self.c_n_axis].to_usize().ok(),
+                    )
+                    .unwrap();
 
-                    let c_fact = TypedFact::dt_shape(cast, self.c_fact.shape.clone());
-                    let mut patch = TypedModelPatch::fuse_with_next(
-                        model,
-                        &node,
-                        Self { mmm, c_fact, ..self.clone() },
-                    )?;
-                    patch.dont_apply_twice = Some(format!("Fuse {} into {}", succ, node));
-                    return Ok(Some(patch));
-                }
-            } else if let Some(op) = op.downcast_ref::<ops::math::QScale>() {
+                let c_fact = TypedFact::dt_shape(cast, self.c_fact.shape.clone());
+                let mut patch = TypedModelPatch::fuse_with_next(
+                    model,
+                    &node,
+                    Self { mmm, c_fact, ..self.clone() },
+                )?;
+                patch.dont_apply_twice = Some(format!("Fuse {} into {}", succ, node));
+                return Ok(Some(patch));
+            }
+        }
+
+        if let Some(op) = succ.op_as::<ops::element_wise::ElementWiseOp>().map(|ew| ew.0.as_ref()) {
+            if let Some(op) = op.downcast_ref::<ops::math::QScale>() {
                 return self.fuse_op_with_broadcast(
                     model,
                     node,
@@ -445,7 +450,7 @@ impl LirMatMulUnary {
         let mut other_shape = shape.to_owned();
         for axis_change in self.reshape_post.iter().rev() {
             if axis_change.recip().change_shape(&mut other_shape, true).is_err() {
-                return Ok(None)
+                return Ok(None);
             }
         }
         if other_shape[self.c_m_axis] == self.c_fact.shape[self.c_m_axis]
